import os
from pathlib import Path

from tcim import cmdlib

base_template = """\
[Desktop Entry]
Name={name}
Comment={comment}
Type=Application
Icon=utilities-terminal"""

term_template = base_template + """
Exec=sh -c "{command}; read"
Terminal=true"""

nokeep_template = base_template + """
Exec=sh -c "{command}"
Terminal=true"""

noterm_template = base_template + """
Exec={command}
Terminal=false"""

desktopfiles_dir = Path.home() / ".cache" / "tcim"
directory_file = cmdlib.tcim_conf_dir / "command-menu.directory"

def get_deleted_commands():
    from_env = os.environ.get("XDG_DATA_HOME")
    if not (from_env and (xdg_data_home := Path(from_env)).is_absolute()):
        xdg_data_home = Path.home() / ".local" / "share"

    installed_commands = set(
        file.name for file in (xdg_data_home / "applications").glob("command-*.desktop")
    )
    new_commands = set(file.name for file in desktopfiles_dir.glob("*.desktop"))
    return installed_commands - new_commands


if not directory_file.exists():
    text = (Path(__file__).resolve().parent / "command-menu.directory").read_text()
    directory_file.write_text(text)

for cmd in cmdlib.cmd_dict.values():
    # populate template
    if not cmd.terminal:
        desktop_str = noterm_template.format(
            name=cmd.name, comment=cmd.comment, command=cmd.command
        )
    elif not cmd.keep:
        desktop_str = nokeep_template.format(
            name=cmd.name, comment=cmd.comment, command=cmd.command
        )
    else:
        desktop_str = term_template.format(
            name=cmd.name, comment=cmd.comment, command=cmd.command
        )
    # save .desktop file
    filename = "command-" + cmd.name.replace(" ","-") + ".desktop"
    (desktopfiles_dir / filename).write_text(desktop_str)

# print deleted commands to pipe them into xdg-desktop-menu uninstall
print(" ".join(get_deleted_commands()))



from subprocess import Popen, PIPE
from pathlib import Path

class Command:

    TERMINAL = "xterm"

    def __init__(self, name, comment, command):
        self.name = name
        self.comment = comment
        self.terminal = True
        self.keep = True

        if command.startswith("[NOTERM]"):
            self.command = command[8:]
            self.terminal = False
            self.keep = False
        elif command.startswith("[NOKEEP]"):
            self.command = command[8:]
            self.keep = False
        else:
            self.command = command

    def __str__(self):
        string = self.name
        if self.comment:
            string += " (" + self.comment + ")"
        return string

    def exec(self):
        if not self.terminal:
            Popen([self.command], shell=True)
        elif not self.keep:
            Popen([Command.TERMINAL, '-e', 'eval "' + self.command + '"'])
        else:
            # or sh -c instead of eval
            Popen([Command.TERMINAL, '-e', 'eval "' + self.command + '; read"'])


cmd_dict = {}
tcim_conf_dir = Path.home() / ".config" / "tcim"
commandsfile = tcim_conf_dir / "commands.tsv"

if not tcim_conf_dir.exists():
    tcim_conf_dir.mkdir()

# load commands file
if not commandsfile.exists():
    commandstext = (Path(__file__).resolve().parent / "commands.tsv").read_text()
    commandsfile.write_text(commandstext)
else:
    commandstext = commandsfile.read_text()

# populate dict with Command objects
for lst in (line.split("\t") for line in sorted(commandstext.splitlines())):
    try:
        c = Command(*lst)
        cmd_dict[str(c)] = c
    except TypeError:
        print("faulty line in commands.tsv:", lst)



#!/usr/bin/env python
from setuptools import setup
from pathlib import Path

basedir = Path(__file__).resolve().parent
readme = (basedir / "README.md").read_text()

setup(
    name='tcim',
    version='0.2.0',
    description='terminal commands in menus',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/wups/tcim',
    author='wups',
    license='GNU GPLv3',
    packages=['tcim'],
    scripts=[
        'bin/tcim-dmenu',
        'bin/tcim-update-xdg-menu'
    ],
    package_data={'tcim': ['command-menu.directory', 'commands.tsv']},
)
